==> bplan-base-globals-1.1.0-0b4347.zip: lang/fr/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'fr',
    'language' => 'Français',
    'locale' => 'fr_FR',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value €',
    'currency.format.negative' => '-:value €',
    'currency.iso4217.alpha'   => 'EUR',
    'currency.iso4217.numeric' => 978,
    'currency.name'            => 'Euro',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Centime',
    'currency.subunit.symbol'  => '¢',
    'currency.symbol'          => '€',

    'date.format'       => 'd/m/Y',
    'datetime.format'   => 'd/m/Y H:i',
    'datetime.format+'  => 'd/m/Y H:i:s',
    'datetime.format-+' => 'd/m/Y H:i',
    'datetime.format++' => 'd/m/Y H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => ' ',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Activer',
    'action.add'           => 'Ajouter',
    'action.cancel'        => 'Annuler',
    'action.cancel-upload' => 'Annuler le téléchargement',
    'action.change'        => 'Modifier',
    'action.close'         => 'Fermer',
    'action.confirm'       => 'Confirmer',
    'action.deactivate'    => 'Désactiver',
    'action.delete'        => 'Supprimer',
    'action.edit'          => 'Éditer',
    'action.import'        => 'Importer',
    'action.print'         => 'Imprimer',
    'action.save'          => 'Enregistrer',
    'action.search'        => 'Rechercher',
    'action.sync'          => 'Synchroniser',
    'action.upload'        => 'Téléverser un fichier',
    'action.verify'        => 'Vérifier',
    'action.view'          => 'Voir',

    'languages' => [
        'bg' => 'Bulgare',
        'de' => 'Allemand',
        'en' => 'Anglais',
        'es' => 'Espagnol',
        'fr' => 'Français',
        'hu' => 'Hongrois',
        'it' => 'Italien',
        'lt' => 'Lituanien',
        'pl' => 'Polonais',
        'ro' => 'Roumain',
        'ru' => 'Russe',
        'tr' => 'Turc',
        'uk' => 'Ukrainien',
    ],

    'option.yes' => 'Oui',
    'option.no'  => 'Non',

    'required-hint'   => 'Les champs marqués (<span class="required-marker">:marker</span>) sont obligatoires',
    'required-marker' => '*',

    'select-option.please-select' => ' -- Veuillez sélectionner -- ',

    'status.active'   => 'Actif',
    'status.expired'  => 'Expiré',
    'status.inactive' => 'Inactif',
    'status.invalid'  => 'Invalide',
    'status.loading'  => 'Chargement...',
    'status.not-set'  => 'Non défini',
    'status.valid'    => 'Valide',

];

==> bplan-base-globals-1.2.0-009337.zip: lang/fr/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'fr',
    'language' => 'Français',
    'locale' => 'fr_FR',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value €',
    'currency.format.negative' => '-:value €',
    'currency.iso4217.alpha'   => 'EUR',
    'currency.iso4217.numeric' => 978,
    'currency.name'            => 'Euro',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Centime',
    'currency.subunit.symbol'  => '¢',
    'currency.symbol'          => '€',

    'date.format'       => 'd/m/Y',
    'datetime.format'   => 'd/m/Y H:i',
    'datetime.format+'  => 'd/m/Y H:i:s',
    'datetime.format-+' => 'd/m/Y H:i',
    'datetime.format++' => 'd/m/Y H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => ' ',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Activer',
    'action.add'           => 'Ajouter',
    'action.cancel'        => 'Annuler',
    'action.cancel-upload' => 'Annuler le téléchargement',
    'action.change'        => 'Modifier',
    'action.close'         => 'Fermer',
    'action.confirm'       => 'Confirmer',
    'action.deactivate'    => 'Désactiver',
    'action.delete'        => 'Supprimer',
    'action.edit'          => 'Éditer',
    'action.import'        => 'Importer',
    'action.print'         => 'Imprimer',
    'action.save'          => 'Enregistrer',
    'action.search'        => 'Rechercher',
    'action.sync'          => 'Synchroniser',
    'action.upload'        => 'Téléverser un fichier',
    'action.verify'        => 'Vérifier',
    'action.view'          => 'Voir',

    'languages' => [
        'bg' => 'Bulgare',
        'de' => 'Allemand',
        'en' => 'Anglais',
        'es' => 'Espagnol',
        'fr' => 'Français',
        'hu' => 'Hongrois',
        'it' => 'Italien',
        'lt' => 'Lituanien',
        'pl' => 'Polonais',
        'ro' => 'Roumain',
        'ru' => 'Russe',
        'tr' => 'Turc',
        'uk' => 'Ukrainien',
    ],

    'option.yes' => 'Oui',
    'option.no'  => 'Non',

    'required-hint'   => 'Les champs marqués (<span class="required-marker">:marker</span>) sont obligatoires',
    'required-marker' => '*',

    'select-option.no-options-available' => 'Aucune option disponible',
    'select-option.please-select'        => ' -- Veuillez sélectionner -- ',

    'status.active'   => 'Actif',
    'status.expired'  => 'Expiré',
    'status.inactive' => 'Inactif',
    'status.invalid'  => 'Invalide',
    'status.loading'  => 'Chargement...',
    'status.not-set'  => 'Non défini',
    'status.valid'    => 'Valide',

];
